==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/os/hos42.h <==
/****************************************************************************

  module      : hos42.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: communication
  description : description ...


  last changed: 1999-12-02  14:09
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef HOS42_H
#define HOS42_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#define  USE_OLD_CONPKT

#include "gos00.h"
#include "geo003.h"
#include "gos42.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/

typedef struct tos42_old_conpkt_param_record
{
  int                             sd;
  tsp00_Longuint                  ulMessClass;
  tsp00_Longuint                  ulSenderRef;
  tsp00_Longuint                  ulReceiverRef;
  tsp00_Longuint                  ulServiceType;
  tsp00_Longuint                  ulMaxSegmentSize;
  tsp00_Longuint                  ulPacketSize;
  tsp00_Longuint                  ulMaxDataLen;
  tsp00_Longuint                  ulMinReplySize;
  tsp00_Longuint                  ulSwapType;
  SQL_DBNAMEC                     szSenderServerDB;
  SQL_DBNAMEC                     szReceiverServerDB;
  PID                             pidSenderPID;
  USHORT                          usServicePort;
  tsp00_Longuint                  ulCommState;
  BOOL                            fAcknowledge;
  PATHNAME                        szServerDBRoot;
  PATHNAME                        szServerPgm;
} OLD_CONPKT_PARAM_REC;

typedef OLD_CONPKT_PARAM_REC  *POLD_CONPKT_PARAM_REC;



/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

// --- VOS42C --------------------------------------------------------------

ULONG           sql42c_pipe_send_conpkt( POLD_CONPKT_PARAM_REC     pConPktParamRec,
                                         HANDLE                    hWritePipe,
                                         tsp00_ErrText             pErrText );

ULONG           sql42c_pipe_recv_conpkt( POLD_CONPKT_PARAM_REC     pConPktParamRec,
                                         HANDLE                    hReadPipe,
                                         tsp00_ErrText             pErrText );

void            sql42c_new2old_conpkt  ( POLD_CONPKT_PARAM_REC     pOldConPktParamRec,
                                         PCONPKT_PARAM_REC         pConPktParamRec );

ULONG           sql42c_recv_header( INT                       sd,
                                    ULONG                     ulSwapType,
                                    PULONG                    pulSenderRef,
                                    PULONG                    pulReceiverRef,
                                    PULONG                    pulMessClass,
                                    tsp00_ErrText             pErrText );


ULONG           sql42c_send_packet( INT                             sd,
                                    ULONG                           ulMaxSegmentSize,
                                    struct teo003_CommPacketRecord *pCommPacket,
                                    ULONG                           ulDataLen,
                                    ULONG                           ulClientRef,
                                    ULONG                           ulServerRef,
                                    ULONG                           ulMessClass,
                                    ULONG                           ulCommState,
                                    tsp00_ErrText                   pErrText );

ULONG           sql42c_recv_packet( INT                             sd,
                                    ULONG                           ulSwapType,
                                    struct teo003_CommPacketRecord *pCommPacket,
                                    ULONG                           ulMaxDataLen,
                                    PULONG                          pulDataLen,
                                    PULONG                          pulSenderRef,
                                    PULONG                          pulReceiverRef,
                                    PULONG                          pulMessClass,
                                    tsp00_ErrText                   pErrText );

#endif  /* HOS42_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/os/hos42.h <==
/****************************************************************************

  module      : hos42.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: communication
  description : description ...


  last changed: 1999-12-02  14:09
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef HOS42_H
#define HOS42_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#define  USE_OLD_CONPKT

#include "gos00.h"
#include "geo003.h"
#include "gos42.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/

typedef struct tos42_old_conpkt_param_record
{
  teo00_Socket                    sd;
  tsp00_Uint                      ulMessClass;
  tsp00_Uint                      ulSenderRef;
  tsp00_Uint                      ulReceiverRef;
  tsp00_Uint                      ulServiceType;
  tsp00_Uint                      ulMaxSegmentSize;
  tsp00_Uint                      ulPacketSize;
  tsp00_Uint                      ulMaxDataLen;
  tsp00_Uint                      ulMinReplySize;
  tsp00_Uint                      ulSwapType;
  SQL_DBNAMEC                     szSenderServerDB;
  SQL_DBNAMEC                     szReceiverServerDB;
  PID                             pidSenderPID;
  USHORT                          usServicePort;
  tsp00_Uint                      ulCommState;
  BOOL                            fAcknowledge;
  PATHNAME                        szServerDBRoot;
  PATHNAME                        szServerPgm;
} OLD_CONPKT_PARAM_REC;

typedef OLD_CONPKT_PARAM_REC  *POLD_CONPKT_PARAM_REC;



/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

// --- VOS42C --------------------------------------------------------------

ULONG           sql42c_pipe_send_conpkt( POLD_CONPKT_PARAM_REC     pConPktParamRec,
                                         HANDLE                    hWritePipe,
                                         tsp00_ErrText             pErrText );

ULONG           sql42c_pipe_recv_conpkt( POLD_CONPKT_PARAM_REC     pConPktParamRec,
                                         HANDLE                    hReadPipe,
                                         tsp00_ErrText             pErrText );

void            sql42c_new2old_conpkt  ( POLD_CONPKT_PARAM_REC     pOldConPktParamRec,
                                         PCONPKT_PARAM_REC         pConPktParamRec );

ULONG           sql42c_recv_header( teo00_Socket              sd,
                                    ULONG                     ulSwapType,
                                    PULONG                    pulSenderRef,
                                    PULONG                    pulReceiverRef,
                                    PULONG                    pulMessClass,
                                    tsp00_ErrText             pErrText );


ULONG           sql42c_send_packet( teo00_Socket                    sd,
                                    ULONG                           ulMaxSegmentSize,
                                    struct teo003_CommPacketRecord *pCommPacket,
                                    ULONG                           ulDataLen,
                                    ULONG                           ulClientRef,
                                    ULONG                           ulServerRef,
                                    ULONG                           ulMessClass,
                                    ULONG                           ulCommState,
                                    tsp00_ErrText                   pErrText );

ULONG           sql42c_recv_packet( teo00_Socket                    sd,
                                    ULONG                           ulSwapType,
                                    struct teo003_CommPacketRecord *pCommPacket,
                                    ULONG                           ulMaxDataLen,
                                    PULONG                          pulDataLen,
                                    PULONG                          pulSenderRef,
                                    PULONG                          pulReceiverRef,
                                    PULONG                          pulMessClass,
                                    tsp00_ErrText                   pErrText );

#endif  /* HOS42_H */
